Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2797)

Unified Diff: chrome/browser/net/http_server_properties_manager.h

Issue 9802003: SPDY - persist SPDY settings. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/net/http_server_properties_manager.h
===================================================================
--- chrome/browser/net/http_server_properties_manager.h (revision 127896)
+++ chrome/browser/net/http_server_properties_manager.h (working copy)
@@ -107,26 +107,22 @@
virtual const net::AlternateProtocolMap&
alternate_protocol_map() const OVERRIDE;
- // Gets a reference to the SpdySettings stored for a host.
- // If no settings are stored, returns an empty set of settings.
- virtual const spdy::SpdySettings& GetSpdySettings(
+ // Gets a reference to the SettingsMap stored for a host.
+ // If no settings are stored, returns an empty SettingsMap.
+ virtual const spdy::SettingsMap& GetSpdySettings(
const net::HostPortPair& host_port_pair) const OVERRIDE;
- // Saves settings for a host. Returns true if SpdySettings are persisted.
- virtual bool SetSpdySettings(
- const net::HostPortPair& host_port_pair,
- const spdy::SpdySettings& settings) OVERRIDE;
-
- // Saves an individual setting for a host. Returns true if SpdySetting is
- // persisted.
+ // Saves an individual SPDY setting for a host. Returns true if SPDY setting
+ // is to be persisted.
virtual bool SetSpdySetting(
const net::HostPortPair& host_port_pair,
- const spdy::SpdySetting& setting) OVERRIDE;
+ uint32 id,
+ const spdy::SettingsFlagsAndValue& flags_and_value) OVERRIDE;
- // Clears all spdy_settings.
+ // Clears all SPDY settings.
virtual void ClearSpdySettings() OVERRIDE;
- // Returns all SpdySettings mappings.
+ // Returns all SPDY settings.
virtual const net::SpdySettingsMap& spdy_settings_map() const OVERRIDE;
virtual net::HttpPipelinedHostCapability GetPipelineCapability(

Powered by Google App Engine
This is Rietveld 408576698